==> jc-1.4.0.tar.gz: gnu/java/text/LineBreakIterator.h <==
// public class gnu.java.text.LineBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class 849dcf236db41da6 gnu_java_text_LineBreakIterator
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header gnu_java_text_BaseBreakIterator

#include "gnu/java/text/BaseBreakIterator.h"

#ifndef _JC_gnu_java_text_LineBreakIterator_H_
#define _JC_gnu_java_text_LineBreakIterator_H_

// Forward structure declarations
struct _jc_gnu_java_text_LineBreakIterator$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_text_LineBreakIterator$sub_refs	_jc_gnu_java_text_LineBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_LineBreakIterator$sub_nonrefs	_jc_gnu_java_text_LineBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_LineBreakIterator$refs	_jc_gnu_java_text_LineBreakIterator$refs;
typedef struct _jc_gnu_java_text_LineBreakIterator$nonrefs	_jc_gnu_java_text_LineBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_LineBreakIterator$object	_jc_gnu_java_text_LineBreakIterator$object;

typedef const struct _jc_gnu_java_text_LineBreakIterator$vmethods	_jc_gnu_java_text_LineBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_LineBreakIterator$vtable	_jc_gnu_java_text_LineBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_LineBreakIterator$vtype	_jc_gnu_java_text_LineBreakIterator$vtype;

// Constructors
extern void _jc_gnu_java_text_LineBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *);
extern void _jc_gnu_java_text_LineBreakIterator$method$_init$27c24a9e35df815e(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, struct _jc_gnu_java_text_LineBreakIterator$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_text_LineBreakIterator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *);
extern jboolean _jc_gnu_java_text_LineBreakIterator$method$isClose$22eaa010ce41e77c(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jint);
extern jboolean _jc_gnu_java_text_LineBreakIterator$method$isIdeo$d6d4d3c190f39343(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jchar);
extern jboolean _jc_gnu_java_text_LineBreakIterator$method$isNb$e4efc46f65733c18(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jchar);
extern jint _jc_gnu_java_text_LineBreakIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *);
extern jint _jc_gnu_java_text_LineBreakIterator$method$previous$9ade62028ea90005(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$isClose$22eaa010ce41e77c;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$isIdeo$d6d4d3c190f39343;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$isNb$e4efc46f65733c18;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$next$0a35667a0e69bb19;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$previous$9ade62028ea90005;

// Virtual methods structure
struct _jc_gnu_java_text_LineBreakIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *);
	jboolean	(*isClose$22eaa010ce41e77c)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jint);
	jboolean	(*isIdeo$d6d4d3c190f39343)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jchar);
	jboolean	(*isNb$e4efc46f65733c18)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jchar);
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *);
	jint	(*previous$9ade62028ea90005)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *);
};

// Vtable
struct _jc_gnu_java_text_LineBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
	_jc_gnu_java_text_LineBreakIterator$vmethods	gnu_java_text_LineBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_LineBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_LineBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_LineBreakIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_text_LineBreakIterator$refs {
    _jc_gnu_java_text_LineBreakIterator$sub_refs	gnu_java_text_LineBreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_LineBreakIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_LineBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
    _jc_gnu_java_text_LineBreakIterator$sub_nonrefs	gnu_java_text_LineBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_LineBreakIterator$object {
	_jc_gnu_java_text_LineBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_LineBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_LineBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_LineBreakIterator$vtype _jc_gnu_java_text_LineBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_LineBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_LineBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_LineBreakIterator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/text/LineBreakIterator.h <==
// public class gnu.java.text.LineBreakIterator

// class file dependencies
// @dep_class 476c0dd5f88e2bbd gnu_java_text_BaseBreakIterator
// @dep_class 849dcf236db41da6 gnu_java_text_LineBreakIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 44db16a713f84af5 java_text_BreakIterator

// header file dependencies
// @dep_header gnu_java_text_BaseBreakIterator

#include "gnu/java/text/BaseBreakIterator.h"

#ifndef _JC_gnu_java_text_LineBreakIterator_H_
#define _JC_gnu_java_text_LineBreakIterator_H_

// Forward structure declarations
struct _jc_gnu_java_text_LineBreakIterator$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_text_LineBreakIterator$sub_refs	_jc_gnu_java_text_LineBreakIterator$sub_refs;
typedef struct _jc_gnu_java_text_LineBreakIterator$sub_nonrefs	_jc_gnu_java_text_LineBreakIterator$sub_nonrefs;
typedef struct _jc_gnu_java_text_LineBreakIterator$refs	_jc_gnu_java_text_LineBreakIterator$refs;
typedef struct _jc_gnu_java_text_LineBreakIterator$nonrefs	_jc_gnu_java_text_LineBreakIterator$nonrefs;
typedef struct _jc_gnu_java_text_LineBreakIterator$object	_jc_gnu_java_text_LineBreakIterator$object;

typedef const struct _jc_gnu_java_text_LineBreakIterator$vmethods	_jc_gnu_java_text_LineBreakIterator$vmethods;
typedef const struct _jc_gnu_java_text_LineBreakIterator$vtable	_jc_gnu_java_text_LineBreakIterator$vtable;
typedef const struct _jc_gnu_java_text_LineBreakIterator$vtype	_jc_gnu_java_text_LineBreakIterator$vtype;

// Constructors
extern void _jc_gnu_java_text_LineBreakIterator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_text_LineBreakIterator$method$_init$27c24a9e35df815e(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, struct _jc_gnu_java_text_LineBreakIterator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_text_LineBreakIterator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_LineBreakIterator$method$isClose$22eaa010ce41e77c(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_LineBreakIterator$method$isIdeo$d6d4d3c190f39343(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_text_LineBreakIterator$method$isNb$e4efc46f65733c18(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jchar) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_LineBreakIterator$method$next$0a35667a0e69bb19(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_text_LineBreakIterator$method$previous$9ade62028ea90005(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$isClose$22eaa010ce41e77c;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$isIdeo$d6d4d3c190f39343;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$isNb$e4efc46f65733c18;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$next$0a35667a0e69bb19;
extern _jc_method _jc_gnu_java_text_LineBreakIterator$method_info$previous$9ade62028ea90005;

// Virtual methods structure
struct _jc_gnu_java_text_LineBreakIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*isClose$22eaa010ce41e77c)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*isIdeo$d6d4d3c190f39343)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jboolean	(*isNb$e4efc46f65733c18)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *, jchar) _JC_JCNI_ATTR;
	jint	(*next$0a35667a0e69bb19)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *) _JC_JCNI_ATTR;
	jint	(*previous$9ade62028ea90005)(_jc_env *, struct _jc_gnu_java_text_LineBreakIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_text_LineBreakIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_BreakIterator$vmethods	java_text_BreakIterator;
	_jc_gnu_java_text_BaseBreakIterator$vmethods	gnu_java_text_BaseBreakIterator;
	_jc_gnu_java_text_LineBreakIterator$vmethods	gnu_java_text_LineBreakIterator;
};

// Vtype
struct _jc_gnu_java_text_LineBreakIterator$vtype {
	_jc_type			type;
	_jc_gnu_java_text_LineBreakIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_text_LineBreakIterator$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_text_LineBreakIterator$refs {
    _jc_gnu_java_text_LineBreakIterator$sub_refs	gnu_java_text_LineBreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_refs	gnu_java_text_BaseBreakIterator;
    _jc_java_text_BreakIterator$sub_refs	java_text_BreakIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_text_LineBreakIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_text_LineBreakIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_BreakIterator$sub_nonrefs	java_text_BreakIterator;
    _jc_gnu_java_text_BaseBreakIterator$sub_nonrefs	gnu_java_text_BaseBreakIterator;
    _jc_gnu_java_text_LineBreakIterator$sub_nonrefs	gnu_java_text_LineBreakIterator;
};

// Object instance structure
struct _jc_gnu_java_text_LineBreakIterator$object {
	_jc_gnu_java_text_LineBreakIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_text_LineBreakIterator$vtype	*vtype;
	_jc_gnu_java_text_LineBreakIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_text_LineBreakIterator$vtype _jc_gnu_java_text_LineBreakIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_text_LineBreakIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_text_LineBreakIterator$class_object;

#endif	/* _JC_gnu_java_text_LineBreakIterator_H_ */
